Type Alias Transfer

pub type Transfer = Consignment<true>;

Aliased Type

struct Transfer {
    pub version: ContainerVer,
    pub transfer: bool,
    pub schema: Schema<Schema<()>>,
    pub ifaces: Confined<BTreeMap<IfaceId, IfacePair>, 0, 255>,
    pub supplements: Confined<BTreeSet<ContractSuppl>, 0, 255>,
    pub genesis: Genesis,
    pub terminals: Confined<BTreeMap<BundleId, Terminal>, 0, 65535>,
    pub bundles: Confined<Vec<AnchoredBundle>, 0, 4294967295>,
    pub extensions: Confined<Vec<Extension>, 0, 4294967295>,
    pub attachments: Confined<BTreeMap<AttachId, Confined<Vec<u8>, 0, 16777215>>, 0, 65535>,
    pub signatures: Confined<BTreeMap<ContentId, ContentSigs>, 0, 255>,
    /* private fields */
}

Fields

version: ContainerVer

Version.

transfer: bool

Specifies whether the consignment contains information about state transfer (true), or it is just a consignment with an information about a contract.

schema: Schema<Schema<()>>

Schema (plus root schema, if any) under which contract is issued.

ifaces: Confined<BTreeMap<IfaceId, IfacePair>, 0, 255>

Interfaces supported by the contract.

supplements: Confined<BTreeSet<ContractSuppl>, 0, 255>

Known supplements.

genesis: Genesis

Genesis data.

terminals: Confined<BTreeMap<BundleId, Terminal>, 0, 65535>

Set of seals which are history terminals.

bundles: Confined<Vec<AnchoredBundle>, 0, 4294967295>

Data on all anchored state transitions contained in the consignments.

extensions: Confined<Vec<Extension>, 0, 4294967295>

Data on all state extensions contained in the consignments.

attachments: Confined<BTreeMap<AttachId, Confined<Vec<u8>, 0, 16777215>>, 0, 65535>

Data containers coming with this consignment. For the purposes of in-memory consignments we are restricting the size of the containers to 24 bit value (RGB allows containers up to 32-bit values in size).

signatures: Confined<BTreeMap<ContentId, ContentSigs>, 0, 255>

Signatures on the pieces of content which are the part of the consignment.

Implementations

Source

impl Transfer

pub fn transfer_id(&self) -> TransferId