Module defines API used by providers of persistent data for RGB contracts.
These data include:
Stash: a consensus-critical data for client-side-validation which must be preserved and backed up.rgb::ContractState, updated with each enclosed consignment and disclosure.- Index over stash, which simplifies construction of a new consignments.
Inventory, which abstracts stash, contract states and index for complex operations requiring participation of all of them.
2-4 data can be re-computed from the stash in case of loss or corruption.
Re-exports
Modules
Enums
- Consigner
Error - Inventory
Data Error - Inventory
Error - Inventory
Inconsistency - These errors indicate internal business logic error. We report them instead of panicking to make sure that the software doesn’t crash and gracefully handles situation, allowing users to report the problem back to the devs.
- Stash
Error - Stash
Inconsistency